@@ -1,7 +1,15 @@
+package org.jmx4perl.handler;
+
+import org.jmx4perl.JmxRequest;
+import org.jmx4perl.converter.attribute.ObjectToJsonConverter;
+
+import javax.management.*;
+import java.lang.reflect.InvocationTargetException;
+
 /*
  * jmx4perl - WAR Agent for exporting JMX via JSON
  *
- * Copyright (C) 2009 Roland Hu§, roland@cpan.org
+ * Copyright (C) 2009 Roland Huß, roland@cpan.org
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,17 +25,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * A commercial license is available as well. You can either apply the GPL or
- * obtain a commercial license for closed source development. Please contact
- * roland@cpan.org for further information.
+ * A commercial license is available as well. Please contact roland@cpan.org for
+ * further details.
  */
-package org.jmx4perl.handler;
-
-import org.jmx4perl.JmxRequest;
-import org.jmx4perl.converter.attribute.AttributeConverter;
-
-import javax.management.*;
-import java.lang.reflect.InvocationTargetException;
 
 /**
  * @author roland
@@ -35,10 +35,10 @@ import java.lang.reflect.InvocationTargetException;
  */
 public class WriteHandler extends RequestHandler {
 
-    private AttributeConverter attributeConverter;
+    private ObjectToJsonConverter objectToJsonConverter;
 
-    public WriteHandler(AttributeConverter pAttributeConverter) {
-        attributeConverter = pAttributeConverter;
+    public WriteHandler(ObjectToJsonConverter pObjectToJsonConverter) {
+        objectToJsonConverter = pObjectToJsonConverter;
     }
 
     public JmxRequest.Type getType() {
@@ -82,7 +82,7 @@ public class WriteHandler extends RequestHandler {
                     " found for MBean " + request.getObjectNameAsString());
         }
         String type = aInfo.getType();
-        Object[] values = attributeConverter.getValues(type,oldValue,request);
+        Object[] values = objectToJsonConverter.getValues(type,oldValue,request);
         Attribute attribute = new Attribute(request.getAttributeName(),values[0]);
         server.setAttribute(request.getObjectName(),attribute);
         return values[1];
