@@ -23,7 +23,7 @@ JMX::Jmx4Perl::Agent - JSON-HTTP based acess to a remote JMX agent
 
 =head1 SYNOPSIS
 
- my $agent = new JMX::Jmx4Perl(mode=>"agent", url => "http://jeeserver/j4p-agent");
+ my $agent = new JMX::Jmx4Perl(mode=>"agent", url => "http://jeeserver/j4p");
  my $answer = $agent->get_attribute("java.lang:type=Memory","HeapMemoryUsage");
  print Dumper($answer);
 
@@ -61,7 +61,7 @@ Creates a new local agent for a given url
 
 The url where the agent is deployed. This is a mandatory parameter. The url
 must include the context within the server, which is typically based on the
-name of the war archive. Example: C<http://localhost:8080/j4p-agent> for a drop
+name of the war archive. Example: C<http://localhost:8080/j4p> for a drop
 in deployment of the agent in a standard Tomcat's webapp directory.
 
 =item timeout => <timeout>
@@ -106,7 +106,12 @@ sub init {
                 $ua->proxy($k,$proxy->{$k});
             }
         } else {
-            $ua->proxy('http',$proxy);
+            if ($self->cfg('url') =~ m|^(.*?)://|) {
+                # Set proxy for URL scheme used
+                $ua->proxy($1,$proxy);
+            } else {
+                $ua->proxy('http',$proxy);
+            }
         }
     }
     $self->{ua} = $ua;
@@ -173,25 +178,36 @@ sub request_url {
     my $request = shift;
     my $url = $self->cfg('url') || croak "No base url given in configuration";
     $url .= "/" unless $url =~ m|/$|;
+    
     my $type = $request->get("type");
-    $url .= $type . "/";
-    $url .= $self->_escape($request->get("mbean"));
+    my $req = $type . "/";
+    $req .= $self->_escape($request->get("mbean"));
     if ($type eq READ) {
-        $url .= "/" . $self->_escape($request->get("attribute"));
-        $url .= "/" . $self->_escape($request->get("path")) if defined($request->get("path"));
+        $req .= "/" . $self->_escape($request->get("attribute"));
+        $req .= $self->_extract_path($request->get("path"));
     } elsif ($type eq WRITE) {
-        $url .= "/" . $self->_escape($request->get("attribute"));
-        $url .= "/" . $self->_escape($self->_null_escape($request->get("value")));
-        $url .= "/" . $self->_escape($request->get("path")) if defined($request->get("path"));
+        $req .= "/" . $self->_escape($request->get("attribute"));
+        $req .= "/" . $self->_escape($self->_null_escape($request->get("value")));
+        $req .= $self->_extract_path($request->get("path"));
     } elsif ($type eq LIST) {
-        $url .= "/" . $self->_escape($request->get("path")) if defined($request->get("path"));
+        $req .= $self->_extract_path($request->get("path"));
     } elsif ($type eq EXEC) {
-        $url .= "/" . $self->_escape($request->get("operation"));
-        $url .= "/" . $self->_escape($self->_null_escape($_)) for @{$request->get("args")};
+        $req .= "/" . $self->_escape($request->get("operation"));
+        $req .= "/" . $self->_escape($self->_null_escape($_)) for @{$request->get("args")};
     } elsif ($type eq SEARCH) {
         # Nothing further to append.
     }
-    return $url;
+    # Squeeze multiple slashes
+    $req =~ s|/{2,}|/|g;
+    return $url . $req;
+}
+
+# Extract path by splitting it up at "/", escape the parts, and join them again
+sub _extract_path {
+    my $self = shift;
+    my $path = shift;
+    return "" unless $path;
+    return "/" . join("/",map { $self->_escape($_) } split(m|/|,$path));
 }
 
 # Escape '/' which are used as separators by using "/-/" as an escape sequence
@@ -202,6 +218,7 @@ sub request_url {
 sub _escape {
     my $self = shift;
     my $input = shift;
+    my $opts = { @_ };
     $input =~ s|(/+)|"/" . ('-' x length($1)) . "/"|eg;
     $input =~ s|-/$|+/|; # The last slash needs a special escape
     return URI::Escape::uri_escape_utf8($input,"^A-Za-z0-9\-_.!~*'()/");   # Added "/" to
